/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.soap;

import jakarta.jws.WebService;
import jakarta.jws.soap.SOAPBinding;
import org.apache.hello_world_soap_action.WrappedGreeter;

@WebService(endpointInterface = "org.apache.hello_world_soap_action.WrappedGreeter",
            serviceName = "WrappedSOAPService")
@SOAPBinding(style = SOAPBinding.Style.RPC, use = SOAPBinding.Use.ENCODED)
public class RPCEncodedSoapActionGreeterImpl implements WrappedGreeter {

    public String sayHiRequestWrapped(String in) {
        return "sayHi";
    }

    public String sayHiRequest2Wrapped(String in) {
        return "sayHi2";
    }

}
